@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -82,9 +82,7 @@ KNoteDisplayConfigWidget::KNoteDisplayConfigWidget(bool defaults, QWidget *paren
     layout->setRowStretch(6, 1);
 }
 
-KNoteDisplayConfigWidget::~KNoteDisplayConfigWidget()
-{
-}
+KNoteDisplayConfigWidget::~KNoteDisplayConfigWidget() = default;
 
 void KNoteDisplayConfigWidget::load(NoteShared::NoteDisplayAttribute *attr)
 {
